@@ -3,9 +3,8 @@
 
 use anyhow::Result;
 use clap::Parser;
-use console::Style;
 use crossterm::tty::IsTty;
-use mediatype::media_type;
+use owo_colors::OwoColorize;
 use rustyline::completion::{Completer, Pair};
 use rustyline::error::ReadlineError;
 use rustyline::highlight::{Highlighter, MatchingBracketHighlighter};
@@ -21,13 +20,13 @@ use sloggers::{
 use std::borrow::Cow;
 use std::fs::File;
 use std::io;
-use std::io::Read;
-use yozuk::{ModelSet, Yozuk, YozukError};
+use std::io::{Read, Write};
+use sys_locale::get_locale;
+use yozuk::{ModelSet, Yozuk};
 use yozuk_sdk::prelude::*;
 
 mod args;
 mod printer;
-mod server;
 
 use args::*;
 use printer::*;
@@ -67,8 +66,15 @@ impl App {
         builder.destination(Destination::Stderr);
         let logger = builder.build().unwrap();
 
+        let i18n = I18n {
+            locale: get_locale(),
+            timezone: localzone::get_local_zone(),
+            ..Default::default()
+        };
+
         let zuk = Yozuk::builder()
             .config(config)
+            .i18n(i18n)
             .logger(logger)
             .build(ModelSet::from_data(yozuk_bundle::MODEL_DATA)?);
 
@@ -76,9 +82,10 @@ impl App {
     }
 
     fn run(self) -> Result<()> {
-        #[cfg(feature = "http-server")]
-        if let Some(addr) = self.args.server_addr {
-            return server::start(addr, self.args.cors_origin, self.zuk);
+        if let Some(dump_dst) = self.args.dump_model {
+            let mut out = File::create(dump_dst)?;
+            out.write_all(yozuk_bundle::MODEL_DATA)?;
+            return Ok(());
         }
 
         let stdin = io::stdin();
@@ -122,35 +129,30 @@ impl App {
         let printer = TerminalPrinter::new();
 
         let commands = if self.args.run {
-            Ok(vec![CommandArgs::new().add_args_iter(&self.args.query)])
+            vec![CommandArgs::new().add_args_iter(&self.args.query)]
         } else {
             self.zuk.get_commands(tokens, streams)
         };
 
-        match commands {
-            Ok(commands) => {
-                if self.args.dry_run {
-                    printer.print_commands(&commands)?;
-                    return Ok(());
-                }
+        if commands.is_empty() {
+            printer.print_error_str("Sorry, I can't understand your request.")?;
+            if let Some(suggest) = self.zuk.suggest(tokens) {
+                printer.print_suggest(&suggest)?;
+            }
+        } else {
+            if self.args.dry_run {
+                printer.print_commands(&commands)?;
+                return Ok(());
+            }
 
-                let result = self.zuk.run_commands(commands, streams);
+            let result = self.zuk.run_commands(commands, streams, None);
 
-                match result {
-                    Ok(output) => printer.print_result(&output)?,
-                    Err(YozukError::CommandError { errors }) => {
-                        printer.print_error(&errors)?;
-                    }
-                    _ => (),
+            match result {
+                Ok(output) => printer.print_result(&output)?,
+                Err(errors) => {
+                    printer.print_error(&errors)?;
                 }
             }
-            Err(YozukError::UnintelligibleRequest { suggest }) => {
-                printer.print_error_str("Sorry, I can't understand your request.")?;
-                if let Some(suggest) = suggest {
-                    printer.print_suggest(&suggest)?;
-                }
-            }
-            _ => (),
         }
 
         Ok(())
@@ -159,12 +161,6 @@ impl App {
     fn start_repl(&self) -> Result<()> {
         let mut rl = Editor::new();
 
-        let style = if console::colors_enabled() {
-            Style::new().bold().blue()
-        } else {
-            Style::new()
-        };
-
         let prompt = "» ";
         let helper = YozukHelper {
             highlighter: MatchingBracketHighlighter::new(),
@@ -173,7 +169,7 @@ impl App {
             validator: MatchingBracketValidator::new(),
         };
         rl.set_helper(Some(helper));
-        rl.helper_mut().expect("No helper").colored_prompt = format!("{}", style.apply_to(&prompt));
+        rl.helper_mut().expect("No helper").colored_prompt = format!("{}", prompt.bold().blue());
 
         println!("Hi. I'm Yozuk. How may I assist you?");
         loop {
